/*
 * Copyright (C) 2010 EPFL (Ecole Polytechnique fédérale de Lausanne)
 * Transport and Mobility Laboratory (Transp-OR)
 *
 * This file is part of COBI.
 *
 * COBI is free software; you can redistribute it and/or modify it under the
 * terms of the GNU General Public License as published by the Free Software
 * Foundation; either version 3 of the License, or (at your option) any later
 * version.
 *
 * COBI is distributed in the hope that it will be useful, but WITHOUT ANY
 * WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
 * FOR A PARTICULAR PURPOSE. See the GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License along with
 * COBI; if not, write to the Free Software Foundation, Inc., 59 Temple Place,
 * Suite 330, Boston, MA 02111-1307 USA.
 *
 * Author: Javier Cruz-Mota
 *         javier.cruz{AT}epfl.ch
 *         http://transp-or2.epfl.ch/pagesPerso/javier.php
 *
 */

#ifndef COBI_H
#define COBI_H

#include <QtGui/QMainWindow>
#include "ui_Cobi.h"

#include <QTimer>
#include <QMutex>

#include "ReadVideoThread.h"
#include "InfoWindow.h"
#include "LoadWindow.h"
#include "VideoData.h"
#include "CobiImage.h"
#include "ReadBufferWindow.h"
#include "ProcessVideoThread.h"
#include "WriteVideoThread.h"
#include "OutputQualityWindow.h"


// Main class
class Cobi : public QMainWindow
{
    Q_OBJECT

public:
    Cobi(QWidget *parent = 0);
    ~Cobi();
    bool isVideoLoaded();

signals:
	void stopReadingThread(void);
	void stopProcessingThread(void);

private slots:
	void on_actionInfo_activated(void);
	void on_actionLoadVideoFile_activated(void);
	void on_playButton_clicked(void);
	void on_pauseButton_clicked(void);
	void on_stopButton_clicked(void);
	void on_actionReadBuffer_activated(void);
	void on_checkBox_stateChanged(void);
	void on_actionQuit_activated(void);
	void updateShowedImages(void);
	void newReceivedImage(void);
	void canImagesBeShowed(void);
	void setTimingIsOK(void);
	void lastOriginalFramePushed(void);
	void lastProcessedFramePushed(void);
	void firstFrameAvailable(void);
	void on_actionOutputQuality_activated(void);
	void errorWriting(void);

private:
    bool loadVideo(void);
    void clearReproduction(bool clearPlayingSurface);
    void refreshStatusBar(void);
    Ui::CobiClass ui;
    bool videoLoaded;
    bool playing;
    bool paused;
	bool timingIsOK;
	bool lastOriginalFrame;
	bool lastProcessedFrame;
	bool savingOutput;
    int bufferSize;
    int outputQuality;
	double period;
	double fps;
	QString videoPath;
	QTimer *refreshTimer;
    QMutex originalImageMutex;
    QMutex processInputImageMutex;
    QMutex processedImageMutex;
    QMutex outputImageMutex;
    CobiImageList originalImage;
    CobiImageList processInputImage;
    CobiImageList processedImage;
    CobiImageList outputImage;
    VideoData *loadedVideoData;
	ReadVideoThread *readingThread;
	ProcessVideoThread *processingThread;
	WriteVideoThread *writingThread;
    GLuint originalTextureName;
    GLuint processedTextureName;
};

#endif // COBI_H
