/*
 * Copyright (C) 2010 EPFL (Ecole Polytechnique fédérale de Lausanne)
 * Transport and Mobility Laboratory (Transp-OR)
 *
 * This file is part of COBI.
 *
 * COBI is free software; you can redistribute it and/or modify it under the
 * terms of the GNU General Public License as published by the Free Software
 * Foundation; either version 3 of the License, or (at your option) any later
 * version.
 *
 * COBI is distributed in the hope that it will be useful, but WITHOUT ANY
 * WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
 * FOR A PARTICULAR PURPOSE. See the GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License along with
 * COBI; if not, write to the Free Software Foundation, Inc., 59 Temple Place,
 * Suite 330, Boston, MA 02111-1307 USA.
 *
 * Author: Javier Cruz-Mota
 *         javier.cruz{AT}epfl.ch
 *         http://transp-or2.epfl.ch/pagesPerso/javier.php
 *
 */

#ifndef COBIIMAGE_H_
#define COBIIMAGE_H_

#include <QImage>
#include <QtOpenGL/QGLWidget>
#include <cv.h>
#include <list>

// Class that contains a QImage, a QImage in OpenGL format and an IplImage (OpenCV)
class CobiImage {
public:
	CobiImage();
	CobiImage(const CobiImage& ci);
	CobiImage(const unsigned char *data, int width, int height, bool gl, bool ocv);
	CobiImage& operator=(const CobiImage& pI);
	~CobiImage();

	void loadImage(const unsigned char *buffer, int width, int height, bool gl, bool ocv);
	void refreshQFromOCV(void);
	void refreshGLImage(void);
	void refreshOCVImage(void);
	void loadGLImage(void);
	void loadOCVImage(void);

	bool isGLUsed(void) const;
	bool isOCVUsed(void) const;

	const QImage* getQImage() const;
	QImage* getQImage();
	int getQWidth() const;
	int getQHeight() const;
	unsigned char* getQData();

	const QImage* getGLImage() const;
	QImage* getGLImage();
	int getGLWidth() const;
	int getGLHeight() const;
	int getGLWidth();
	int getGLHeight();
	unsigned char* getGLData();

	const IplImage* getOCVImage() const;
	IplImage* getOCVImage();
	int getOCVWidth() const;
	int getOCVHeight() const;
	int getOCVWidth();
	int getOCVHeight();
	char* getOCVData();

protected:
	QImage image;
	QImage glImage;
	IplImage *ocvImage;
	bool imageLoaded;
	bool useGL;
	bool useOCV;
};

// List of Cobi Images
typedef std::list<CobiImage> CobiImageList;

#endif /* COBIIMAGE_H_ */
