/*
 * Copyright (C) 2010 EPFL (Ecole Polytechnique fédérale de Lausanne)
 * Transport and Mobility Laboratory (Transp-OR)
 *
 * This file is part of COBI.
 *
 * COBI is free software; you can redistribute it and/or modify it under the
 * terms of the GNU General Public License as published by the Free Software
 * Foundation; either version 3 of the License, or (at your option) any later
 * version.
 *
 * COBI is distributed in the hope that it will be useful, but WITHOUT ANY
 * WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
 * FOR A PARTICULAR PURPOSE. See the GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License along with
 * COBI; if not, write to the Free Software Foundation, Inc., 59 Temple Place,
 * Suite 330, Boston, MA 02111-1307 USA.
 *
 * Author: Javier Cruz-Mota
 *         javier.cruz{AT}epfl.ch
 *         http://transp-or2.epfl.ch/pagesPerso/javier.php
 *
 */

#include "LoadWindow.h"

// Constructor
LoadWindow::LoadWindow(QWidget *parent)
    : QDialog(parent)
{
	ui.setupUi(this);

	this->parent = parent;

	this->model = new QDirModel;
	this->model->setReadOnly(true);
	this->model->setFilter(QDir::AllDirs | QDir::Files | QDir::Drives | QDir::NoDotAndDotDot);
	QStringList filters;
	filters << "*.avi" << "*.mpg" << "*.mpeg" << "*.mov"; // Only files with these extensions are shown
	this->model->setNameFilters(filters);

	ui.treeView->setModel(this->model);
	ui.treeView->setRootIndex(this->model->index(QDir::rootPath()));
	ui.treeView->hideColumn(1);
	ui.treeView->hideColumn(2);
	ui.treeView->hideColumn(3);
	ui.treeView->hideColumn(4);
	ui.treeView->setSelectionMode(QAbstractItemView::SingleSelection);
}

// Destructor
LoadWindow::~LoadWindow()
{
	ui.verticalLayout->removeWidget(ui.loadButton);
	ui.verticalLayout->removeWidget(ui.cancelButton);
	ui.verticalLayout->removeItem(ui.verticalSpacer);
	ui.verticalLayout->removeWidget(ui.homeButton);

	delete model;
	delete ui.verticalLayout;
	delete ui.loadButton;
	delete ui.cancelButton;
	delete ui.verticalSpacer;
	delete ui.homeButton;
	delete ui.treeView;
	delete ui.verticalLayoutWidget;
}

// Called when "Home" button is clicked
void LoadWindow::on_homeButton_clicked()
{
	ui.treeView->scrollTo(this->model->index(QDir::homePath()));
}

// Called when "Load" button is clicked
void LoadWindow::on_loadButton_clicked()
{
	videoPath = this->model->filePath(ui.treeView->currentIndex());
	videoFile = this->model->fileName(ui.treeView->currentIndex());
	this->accept();
}

// Returns the full path to the chosen video file
QString LoadWindow::getVideoPath()
{
	 return videoPath;
}

// Returns the file name of the chosen video file
QString LoadWindow::getVideoFile()
{
	return videoFile;
}

