/*
 * Copyright (C) 2010 EPFL (Ecole Polytechnique fédérale de Lausanne)
 * Transport and Mobility Laboratory (Transp-OR)
 *
 * This file is part of COBI.
 *
 * COBI is free software; you can redistribute it and/or modify it under the
 * terms of the GNU General Public License as published by the Free Software
 * Foundation; either version 3 of the License, or (at your option) any later
 * version.
 *
 * COBI is distributed in the hope that it will be useful, but WITHOUT ANY
 * WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
 * FOR A PARTICULAR PURPOSE. See the GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License along with
 * COBI; if not, write to the Free Software Foundation, Inc., 59 Temple Place,
 * Suite 330, Boston, MA 02111-1307 USA.
 *
 * Author: Javier Cruz-Mota
 *         javier.cruz{AT}epfl.ch
 *         http://transp-or2.epfl.ch/pagesPerso/javier.php
 *
 */

#ifndef PROCESSVIDEOTHREAD_H_
#define PROCESSVIDEOTHREAD_H_

#include <QThread>
#include <QMutex>
#include <QTime>
#include "CobiImage.h"

// Class for the thread that processes the input video
class ProcessVideoThread : public QThread
{
	Q_OBJECT

public:
	ProcessVideoThread(QObject *parent, CobiImageList *ii, CobiImageList *pi, CobiImageList *oi, int *ls, bool *lf, bool so, QMutex *im, QMutex *pm, QMutex *om);
	virtual ~ProcessVideoThread();
	int getElapsedTime(void);
	double getFPS(void);

signals:
	void newPushedImage(void);
	void lastFrameProcessed(void);
	void checkImagesUpdate(void);

private slots:
	void stopProcessing(void);

protected:
	void run();
	virtual void process(void);
    QMutex *processInputImageMutex;
    QMutex *processedImageMutex;
    QMutex *outputImageMutex;
    QTime elapsedTime;
    int elapsedTimeValue;
	CobiImageList *inputImage;
	CobiImageList *processedImage;
	CobiImageList *outputImage;
	CobiImage currentImage;
	int *listSize;
	bool *lastFrameRead;
	bool stopLoop;
	bool savingOutput;
};

#endif /* PROCESSVIDEOTHREAD_H_ */
