/*
 * Copyright (C) 2010 EPFL (Ecole Polytechnique fédérale de Lausanne)
 * Transport and Mobility Laboratory (Transp-OR)
 *
 * This file is part of COBI.
 *
 * COBI is free software; you can redistribute it and/or modify it under the
 * terms of the GNU General Public License as published by the Free Software
 * Foundation; either version 3 of the License, or (at your option) any later
 * version.
 *
 * COBI is distributed in the hope that it will be useful, but WITHOUT ANY
 * WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
 * FOR A PARTICULAR PURPOSE. See the GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License along with
 * COBI; if not, write to the Free Software Foundation, Inc., 59 Temple Place,
 * Suite 330, Boston, MA 02111-1307 USA.
 *
 * Author: Javier Cruz-Mota
 *         javier.cruz{AT}epfl.ch
 *         http://transp-or2.epfl.ch/pagesPerso/javier.php
 *
 */

#ifndef READVIDEOTHREAD_H_
#define READVIDEOTHREAD_H_

#include <QThread>
#include <QMutex>
#include "VideoData.h"
#include "CobiImage.h"

// Class for the thread that reads the video
class ReadVideoThread : public QThread
{
	Q_OBJECT

public:
	ReadVideoThread(QObject *parent, VideoData *vd, CobiImageList *oi, CobiImageList *ii, int *ls, QMutex *om, QMutex *im);
    ~ReadVideoThread(){};

signals:
    void newPushedImage(void);
	void lastFrameRead(void);
	void checkImagesUpdate(void);
	void firstFrameRead(void);

private slots:
	void stopReading(void);

protected:
    virtual void run();

private:
    VideoData *loadedVideoData;
    QMutex *originalImageMutex;
    QMutex *processInputImageMutex;
    CobiImageList *originalImage;
    CobiImageList *inputImage;
    int *listSize;
    bool stopLoop;
};

#endif /* READVIDEOTHREAD_H_ */
