/*
 * Copyright (C) 2010 EPFL (Ecole Polytechnique fédérale de Lausanne)
 * Transport and Mobility Laboratory (Transp-OR)
 *
 * This file is part of COBI.
 *
 * COBI is free software; you can redistribute it and/or modify it under the
 * terms of the GNU General Public License as published by the Free Software
 * Foundation; either version 3 of the License, or (at your option) any later
 * version.
 *
 * COBI is distributed in the hope that it will be useful, but WITHOUT ANY
 * WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
 * FOR A PARTICULAR PURPOSE. See the GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License along with
 * COBI; if not, write to the Free Software Foundation, Inc., 59 Temple Place,
 * Suite 330, Boston, MA 02111-1307 USA.
 *
 * Author: Javier Cruz-Mota
 *         javier.cruz{AT}epfl.ch
 *         http://transp-or2.epfl.ch/pagesPerso/javier.php
 *
 */

#ifndef VIDEODATA_H_
#define VIDEODATA_H_

extern "C" {
	#include <libavcodec/avcodec.h>
	#include <libavformat/avformat.h>
	#include <libswscale/swscale.h>
}

#include <QtCore>

// Class to manage the input video
class VideoData
{
public:
	VideoData();
	~VideoData();
	enum FrameState{VIDEOFRAME, LASTVIDEOFRAME, NOVIDEOFRAME};
	bool LoadData(const char *fileName);
	int ReadFrame(AVPacket *packet);
	void ConvertToRGB(void);
	int getWidth(void);
	int getHeight(void);
	uint8_t* getFrameData(void);
	uint8_t* getRGBFrameData(void);
	double getPeriod(void);
	AVCodecContext* getCodecContext(void);
private:
	int videoStream;
	AVFormatContext *pFormatCtx;
    AVCodecContext *pCodecCtx;
    AVCodec *pCodec;
	AVFrame *pFrame;
	AVFrame *pFrameRGB;
	quint8 *imageBuffer;
	quint8 *imageRGBBuffer;
	bool videoDataIsLoaded;
	struct SwsContext *convertContext;
};


#endif /* VIDEODATA_H_ */
