/*
 * Copyright (C) 2010 EPFL (Ecole Polytechnique fédérale de Lausanne)
 * Transport and Mobility Laboratory (Transp-OR)
 *
 * This file is part of COBI.
 *
 * COBI is free software; you can redistribute it and/or modify it under the
 * terms of the GNU General Public License as published by the Free Software
 * Foundation; either version 3 of the License, or (at your option) any later
 * version.
 *
 * COBI is distributed in the hope that it will be useful, but WITHOUT ANY
 * WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
 * FOR A PARTICULAR PURPOSE. See the GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License along with
 * COBI; if not, write to the Free Software Foundation, Inc., 59 Temple Place,
 * Suite 330, Boston, MA 02111-1307 USA.
 *
 * Author: Javier Cruz-Mota
 *         javier.cruz{AT}epfl.ch
 *         http://transp-or2.epfl.ch/pagesPerso/javier.php
 *
 */

#ifndef WRITEVIDEOTHREAD_H_
#define WRITEVIDEOTHREAD_H_

#include <QThread>
#include <QMutex>
#include "CobiImage.h"
#include "VideoData.h"

// Class for the thread that writes the output video
class WriteVideoThread : public QThread
{
	Q_OBJECT

public:
	WriteVideoThread(QObject *parent, CobiImageList *oi, QMutex *om, QString fn, AVCodecContext *ic, int oq);//, const AVCodecContext &cc, const char *fn);
	virtual ~WriteVideoThread();

signals:
	void errorWriting(void);

private slots:
	void stopWriting(void);

private:
	void addVideoStream(void);
	void openVideo(void);
	bool allocPicture(void);
	void fillImage(void);
	void writeVideoFrame(void);
	void closeVideo(void);

protected:
	void run();
    QMutex *outputImageMutex;
	CobiImageList *outputImage;
	CobiImage currentImage;
	bool stopLoop;
	QString fileName;
	int videoBufferSize;
	int outputQuality;
	unsigned long int frameCount;
	uint8_t *videoBuffer;
	uint8_t *pictureBuffer;
	uint8_t *tmpPictureBuffer;
	AVFrame *picture;
	AVFrame *tmpPicture;

	AVOutputFormat *outputFormat;
	AVFormatContext *outputFormatContext;
	AVStream *videoStream;
	AVCodecContext *outputCodecContext;
	AVCodecContext *inputCodecContext;
	struct SwsContext *convertContext;

};

#endif /* WRITEVIDEOTHREAD_H_ */
